@@ -31,10 +31,10 @@ part_bias <- function(plans, shp, dvote, rvote, v = 0.5) {
   dvote <- rlang::eval_tidy(rlang::enquo(dvote), shp)
   rvote <- rlang::eval_tidy(rlang::enquo(rvote), shp)
 
-  if (any(is.na(dvote))) {
+  if (anyNA(dvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg dvote}.')
   }
-  if (any(is.na(rvote))) {
+  if (anyNA(rvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg rvote}.')
   }
   if (length(rvote) != nrow(plans)) {
@@ -80,10 +80,10 @@ part_dseats <- function(plans, shp, dvote, rvote) {
   dvote <- rlang::eval_tidy(rlang::enquo(dvote), shp)
   rvote <- rlang::eval_tidy(rlang::enquo(rvote), shp)
 
-  if (any(is.na(dvote))) {
+  if (anyNA(dvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg dvote}.')
   }
-  if (any(is.na(rvote))) {
+  if (anyNA(rvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg rvote}.')
   }
   if (length(rvote) != nrow(plans)) {
@@ -130,10 +130,10 @@ part_dvs <- function(plans, shp, dvote, rvote) {
   dvote <- rlang::eval_tidy(rlang::enquo(dvote), shp)
   rvote <- rlang::eval_tidy(rlang::enquo(rvote), shp)
 
-  if (any(is.na(dvote))) {
+  if (anyNA(dvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg dvote}.')
   }
-  if (any(is.na(rvote))) {
+  if (anyNA(rvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg rvote}.')
   }
   if (length(rvote) != nrow(plans)) {
@@ -182,10 +182,10 @@ part_egap <- function(plans, shp, dvote, rvote) {
   dvote <- rlang::eval_tidy(rlang::enquo(dvote), shp)
   rvote <- rlang::eval_tidy(rlang::enquo(rvote), shp)
 
-  if (any(is.na(dvote))) {
+  if (anyNA(dvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg dvote}.')
   }
-  if (any(is.na(rvote))) {
+  if (anyNA(rvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg rvote}.')
   }
   if (length(rvote) != nrow(plans)) {
@@ -235,10 +235,10 @@ part_egap_ep <- function(plans, shp, dvote, rvote) {
   dvote <- rlang::eval_tidy(rlang::enquo(dvote), shp)
   rvote <- rlang::eval_tidy(rlang::enquo(rvote), shp)
 
-  if (any(is.na(dvote))) {
+  if (anyNA(dvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg dvote}.')
   }
-  if (any(is.na(rvote))) {
+  if (anyNA(rvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg rvote}.')
   }
   if (length(rvote) != nrow(plans)) {
@@ -289,10 +289,10 @@ part_tau_gap <- function(plans, shp, dvote, rvote, tau = 1) {
   dvote <- rlang::eval_tidy(rlang::enquo(dvote), shp)
   rvote <- rlang::eval_tidy(rlang::enquo(rvote), shp)
 
-  if (any(is.na(dvote))) {
+  if (anyNA(dvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg dvote}.')
   }
-  if (any(is.na(rvote))) {
+  if (anyNA(rvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg rvote}.')
   }
   if (length(rvote) != nrow(plans)) {
@@ -311,6 +311,63 @@ part_tau_gap <- function(plans, shp, dvote, rvote, tau = 1) {
   rep(taugap(tau = tau, dvs = dvs, dseat_vec = dseat_vec, nd = nd), each = nd)
 }
 
+#' Calculate Dilution Asymmetry
+#'
+#' @templateVar plans TRUE
+#' @templateVar shp TRUE
+#' @templateVar dvote TRUE
+#' @templateVar rvote TRUE
+#' @template template_nosf
+#'
+#' @returns A numeric vector. Can be shaped into a district-by-plan matrix.
+#' @export
+#' @concept partisan
+#'
+#' @references
+#' Sanford C. Gordon and Sidak Yntiso. 2024.
+#' Base Rate Neglect and the Diagnosis of Partisan Gerrymanders.
+#' Election Law Journal: Rules, Politics, and Policy. \doi{10.1089/elj.2023.0005}.
+#'
+#' @examples
+#' data(nh)
+#' data(nh_m)
+#' # For a single plan:
+#' part_dil_asym(plans = nh$r_2020, shp = nh, rvote = nrv, dvote = ndv)
+#'
+#' # Or many plans:
+#' part_dil_asym(plans = nh_m[, 3:5], shp = nh, rvote = nrv, dvote = ndv)
+#'
+part_dil_asym <- function(plans, shp, dvote, rvote) {
+
+  plans <- process_plans(plans)
+  dvote <- rlang::eval_tidy(rlang::enquo(dvote), shp)
+  rvote <- rlang::eval_tidy(rlang::enquo(rvote), shp)
+
+  if (anyNA(dvote)) {
+    cli::cli_abort('{.val NA} in argument to {.arg dvote}.')
+  }
+  if (anyNA(rvote)) {
+    cli::cli_abort('{.val NA} in argument to {.arg rvote}.')
+  }
+  if (length(rvote) != nrow(plans)) {
+    cli::cli_abort('{.arg rvote} length and {.arg plans} rows are not equal.')
+  }
+  if (length(dvote) != nrow(plans)) {
+    cli::cli_abort('{.arg dvote} length and {.arg plans} rows are not equal.')
+  }
+
+  nd <- length(unique(plans[, 1]))
+  rcounts <- agg_p2d(vote = rvote, dm = plans, nd = nd)
+  dcounts <- agg_p2d(vote = dvote, dm = plans, nd = nd)
+  half <- floor((rcounts + dcounts) / 2) + 1
+
+  waste_dem <- matrix(ifelse(rcounts > dcounts, dcounts, dcounts - half), nrow = nd)
+  waste_rep <- matrix(ifelse(dcounts > rcounts, rcounts, rcounts - half), nrow = nd)
+
+  dil <- colSums(waste_dem)/sum(dvote) - colSums(waste_rep)/sum(rvote)
+  rep(dil, each = nd)
+}
+
 #' Calculate Mean Median Score
 #'
 #' @templateVar plans TRUE
@@ -344,10 +401,10 @@ part_mean_median <- function(plans, shp, dvote, rvote) {
   dvote <- rlang::eval_tidy(rlang::enquo(dvote), shp)
   rvote <- rlang::eval_tidy(rlang::enquo(rvote), shp)
 
-  if (any(is.na(dvote))) {
+  if (anyNA(dvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg dvote}.')
   }
-  if (any(is.na(rvote))) {
+  if (anyNA(rvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg rvote}.')
   }
   if (length(rvote) != nrow(plans)) {
@@ -398,10 +455,10 @@ part_decl <- function(plans, shp, dvote, rvote, normalize = TRUE, adjust = TRUE)
   dvote <- rlang::eval_tidy(rlang::enquo(dvote), shp)
   rvote <- rlang::eval_tidy(rlang::enquo(rvote), shp)
 
-  if (any(is.na(dvote))) {
+  if (anyNA(dvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg dvote}.')
   }
-  if (any(is.na(rvote))) {
+  if (anyNA(rvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg rvote}.')
   }
   if (length(rvote) != nrow(plans)) {
@@ -462,10 +519,10 @@ part_decl_simple <- function(plans, shp, dvote, rvote) {
   dvote <- rlang::eval_tidy(rlang::enquo(dvote), shp)
   rvote <- rlang::eval_tidy(rlang::enquo(rvote), shp)
 
-  if (any(is.na(dvote))) {
+  if (anyNA(dvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg dvote}.')
   }
-  if (any(is.na(rvote))) {
+  if (anyNA(rvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg rvote}.')
   }
   if (length(rvote) != nrow(plans)) {
@@ -520,10 +577,10 @@ part_resp <- function(plans, shp, dvote, rvote, v = 0.5, bandwidth = 0.01) {
   dvote <- rlang::eval_tidy(rlang::enquo(dvote), shp)
   rvote <- rlang::eval_tidy(rlang::enquo(rvote), shp)
 
-  if (any(is.na(dvote))) {
+  if (anyNA(dvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg dvote}.')
   }
-  if (any(is.na(rvote))) {
+  if (anyNA(rvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg rvote}.')
   }
   if (length(rvote) != nrow(plans)) {
@@ -573,10 +630,10 @@ part_lop_wins <- function(plans, shp, dvote, rvote) {
   dvote <- rlang::eval_tidy(rlang::enquo(dvote), shp)
   rvote <- rlang::eval_tidy(rlang::enquo(rvote), shp)
 
-  if (any(is.na(dvote))) {
+  if (anyNA(dvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg dvote}.')
   }
-  if (any(is.na(rvote))) {
+  if (anyNA(rvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg rvote}.')
   }
   if (length(rvote) != nrow(plans)) {
@@ -627,10 +684,10 @@ part_rmd <- function(plans, shp, dvote, rvote) {
   dvote <- rlang::eval_tidy(rlang::enquo(dvote), shp)
   rvote <- rlang::eval_tidy(rlang::enquo(rvote), shp)
 
-  if (any(is.na(dvote))) {
+  if (anyNA(dvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg dvote}.')
   }
-  if (any(is.na(rvote))) {
+  if (anyNA(rvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg rvote}.')
   }
   if (length(rvote) != nrow(plans)) {
@@ -680,10 +737,10 @@ part_sscd <- function(plans, shp, dvote, rvote) {
   dvote <- rlang::eval_tidy(rlang::enquo(dvote), shp)
   rvote <- rlang::eval_tidy(rlang::enquo(rvote), shp)
 
-  if (any(is.na(dvote))) {
+  if (anyNA(dvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg dvote}.')
   }
-  if (any(is.na(rvote))) {
+  if (anyNA(rvote)) {
     cli::cli_abort('{.val NA} in argument to {.arg rvote}.')
   }
   if (length(rvote) != nrow(plans)) {
