@@ -1,13 +1,14 @@
 // [[Rcpp::interfaces(r, cpp)]]
 #include <RcppArmadillo.h>
+#include <RcppThread.h>
 using namespace Rcpp;
+using namespace arma;
 
-double var_info(IntegerVector m1, IntegerVector m2, NumericVector pop) {
-    int k = max(m1);
-    int V = m1.size();
-    NumericMatrix joint(k);
-    NumericVector p1(k);
-    NumericVector p2(k);
+double var_info(const uvec m1, const uvec m2, const vec pop, int k) {
+    int V = m1.n_elem;
+    mat joint(k, k);
+    vec p1(k);
+    vec p2(k);
 
     double total_pop = 0;
     for (int i = 0; i < V; i++) {
@@ -22,7 +23,7 @@ double var_info(IntegerVector m1, IntegerVector m2, NumericVector pop) {
         for (int j = 0; j < k; j++) {
             double jo = joint(i, j);
             if (jo < 1) continue;
-            varinf -= (jo / total_pop) * (2.0*log(jo) - log(p1[i]) - log(p2[j]));
+            varinf -= (jo / total_pop) * (2.0*std::log(jo) - std::log(p1[i]) - std::log(p2[j]));
         }
     }
 
@@ -39,30 +40,18 @@ double var_info(IntegerVector m1, IntegerVector m2, NumericVector pop) {
  * Only computes pairs (i, j) with j < i
  */
 // [[Rcpp::export(rng = false)]]
-NumericVector var_info_mat(IntegerMatrix m, int i, NumericVector pop) {
-    int N = m.ncol();
+arma::mat var_info_mat(const arma::umat m, const arma::vec pop, int ndists, int ncores) {
+    int N = m.n_cols;
 
-    NumericVector out(N);
-    for (int j = 0; j < i; j++) {
-        out[j] = var_info(m(_, i), m(_, j), pop);
-    }
-
-    return out;
-}
-
-/*
- * `m` has rows = precincts, cols = plans
- * `ref` is the plan we want to compute distances to
- * `pop` is population of precincts
- */
-// [[Rcpp::export(rng = false)]]
-NumericVector var_info_vec(IntegerMatrix m, IntegerVector ref, NumericVector pop) {
-    int N = m.ncol();
-
-    NumericVector out(N);
-    for (int j = 0; j < N; j++) {
-        out[j] = var_info(ref, m(_, j), pop);
-    }
+    mat out(N, N);
+    RcppThread::parallelFor(1, N, [&] (int i) {
+        auto plan_i = m.col(i);
+        for (int j = 0; j < i; j++) {
+            double vi = var_info(plan_i, m.col(j), pop, ndists);
+            out(i, j) = vi;
+            out(j, i) = vi;
+        }
+    }, ncores);
 
     return out;
 }
